@@ -155,7 +155,7 @@ use PPI::Statement::Variable       ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.000';
+	$VERSION = '1.100_01';
 }
 
 # "Normal" statements end at a statement terminator ;
@@ -239,7 +239,7 @@ sub stable {
 # You can insert either a statement, or a non-significant token.
 sub insert_before {
 	my $self    = shift;
-	my $Element = isa($_[0], 'PPI::Element') or return undef;
+	my $Element = isa($_[0], 'PPI::Element') ? shift : return undef;
 	if ( $Element->isa('PPI::Statement') ) {
 		return $self->__insert_before($Element);
 	} elsif ( $Element->isa('PPI::Token') and ! $Element->significant ) {
@@ -251,7 +251,7 @@ sub insert_before {
 # As above, you can insert a statement, or a non-significant token
 sub insert_after {
 	my $self    = shift;
-	my $Element = isa($_[0], 'PPI::Element') or return undef;
+	my $Element = isa($_[0], 'PPI::Element') ? shift : return undef;
 	if ( $Element->isa('PPI::Statement') ) {
 		return $self->__insert_after($Element);
 	} elsif ( $Element->isa('PPI::Token') and ! $Element->significant ) {
