@@ -74,10 +74,11 @@ use UNIVERSAL 'isa';
 use List::MoreUtils ();
 use PPI::Element    ();
 use PPI::Token      ();
+use PPI::Util       ();
 
 use vars qw{$VERSION $errstr};
 BEGIN {
-	$VERSION = '1.000';
+	$VERSION = '1.100_01';
 	$errstr  = '';
 }
 
@@ -135,10 +136,14 @@ sub new {
 		return $self->_error( "No source provided to Tokenizer" );
 
 	} elsif ( ! ref $_[0] ) {
-		local $/ = undef;
-		open( PPIINPUT, '<', $_[0] ) or return("open($_[0]) failed: $!");
-		$self->{source} = <PPIINPUT>;
-		close( PPIINPUT ) or return("close($_[0]) failed: $!");
+		my $source = PPI::Util::_slurp($_[0]);
+		if ( ref $source ) {
+			# Content returned by reference
+			$self->{source} = $$source;
+		} else {
+			# Errors returned as a string
+			return($source);
+		}
 
 	} elsif ( isa($_[0], 'SCALAR') ) {
 		$self->{source} = ${shift()};
@@ -380,15 +385,23 @@ sub decrement_cursor {
 # Returns 0 on EOF
 # Returns undef on error
 sub _fill_line {
-	my $self = shift;
+	my $self   = shift;
+	my $inscan = shift;
 
 	# Get the next line
 	my $line = $self->_get_line;
 	unless ( defined $line ) {
-		# End of file, clean up
-		delete $self->{line};
-		delete $self->{line_cursor};
-		delete $self->{line_length};
+		# End of file
+		unless ( $inscan ) {
+			delete $self->{line};
+			delete $self->{line_cursor};
+			delete $self->{line_length};
+			return 0;
+		}
+
+		# In the scan version, just set the cursor to the end
+		# of the line, and the rest should just cascade out.
+		$self->{line_cursor} = $self->{line_length};
 		return 0;
 	}
 
@@ -452,7 +465,7 @@ sub _process_next_line {
 	$self->{class}->__TOKENIZER__on_line_end( $self );
 
 	# If there are no more source lines, then clean up
-	if ( ref $self->{source} eq 'ARRAY' and ! @{$self->{source}} ) {
+	unless ( ref($self->{source}) eq 'ARRAY' and @{$self->{source}} ) {
 		return $self->_clean_eof;
 	}
 
